@@ -5,26 +5,29 @@ mod builder;
 mod conditions;
 mod operate;
 mod query;
+mod aggregation;
+mod clause;
 
 pub use query::Query;
+pub use aggregation::Aggs;
 
 #[derive(Serialize)]
-pub struct Request<'p, 't, 'o1, 'o2> {
+pub struct Request<'a> {
     auth: u8,
-    project: &'p str,
-    table: &'t str,
+    project: &'a str,
+    table: &'a str,
 
     #[serde(flatten)]
-    operate: operate::Operate<'o1, 'o2>,
+    operate: operate::Operate<'a>,
 }
 
-impl<'p, 't, 'o1, 'o2> Request<'p, 't, 'o1, 'o2> {
-    pub fn project<'a: 'p>(project: &'a str) -> builder::Project<'p> {
+impl<'a> Request<'a> {
+    pub fn project(project: &'a str) -> builder::Project<'a> {
         builder::Project { project }
     }
 }
 
-impl<'p, 't, 'o1, 'o2> std::fmt::Display for Request<'p, 't, 'o1, 'o2> {
+impl<'a> std::fmt::Display for Request<'a> {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         write!(f, "{}", serde_json::to_value(&self).unwrap())
     }
