@@ -3,27 +3,33 @@ use super::*;
 #[derive(Default, Serialize)]
 pub struct Conditions<'a> {
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub(crate) pagination: Option<Pagination>,
+    pub(super) pagination: Option<Pagination>,
     #[serde(rename = "order", skip_serializing_if = "Option::is_none")]
-    pub(crate) orders: Option<HashMap<&'a str, OrderCase>>,
+    pub(super) orders: Option<HashMap<&'a str, OrderCase>>,
 
-    pub(crate) fields: Vec<&'a str>,
-    pub(crate) query: query::Query<'a>,
+    pub(super) fields: Vec<&'a str>,
+    pub(super) query: query::Query<'a>,
+    #[serde(flatten, skip_serializing_if = "Option::is_none")]
+    pub(super) aggs: Option<aggregation::Aggs<'a>>,
 }
 
 impl<'a> Conditions<'a> {
-    pub fn from_query(query: query::Query<'a>) -> Conditions<'a> {
+    pub(super) fn from_query(query: query::Query<'a>) -> Conditions<'a> {
         Conditions {
             query,
             ..Default::default()
         }
     }
 
-    pub fn set_pagination(&mut self, page: u32, page_size: u32) {
+    pub(super) fn aggs(&mut self, aggs: aggregation::Aggs<'a>) {
+        self.aggs = Some(aggs)
+    }
+
+    pub(super) fn pagination(&mut self, page: u32, page_size: u32) {
         self.pagination = Some(Pagination { page, page_size })
     }
 
-    pub fn desc(&mut self, order: &'a str) {
+    pub(super) fn desc(&mut self, order: &'a str) {
         if let Some(orders) = &mut self.orders {
             orders.insert(order, OrderCase::Desc);
         } else {
@@ -31,7 +37,7 @@ impl<'a> Conditions<'a> {
         }
     }
 
-    pub fn asc(&mut self, order: &'a str) {
+    pub(super) fn asc(&mut self, order: &'a str) {
         if let Some(orders) = &mut self.orders {
             orders.insert(order, OrderCase::Asc);
         } else {
@@ -39,11 +45,12 @@ impl<'a> Conditions<'a> {
         }
     }
 
-    pub fn add_field(&mut self, field: &'a str) {
+    pub(super) fn field(&mut self, field: &'a str) {
         self.fields.push(field);
     }
-    pub fn add_fields(&mut self, fields: &'a [String]) {
-        fields.iter().for_each(|field| {
+
+    pub(super) fn fields(&mut self, fields: Vec<&'a str>) {
+        fields.iter().for_each(|&field| {
             self.fields.push(field);
         });
     }
