@@ -2,13 +2,13 @@ use super::*;
 
 #[derive(Serialize)]
 #[serde(untagged)]
-pub enum Operate<'a, 'b> {
+pub(crate) enum Operate<'a> {
     Create {
         data: Vec<serde_json::Value>,
     },
     Get {
         id: &'a str,
-        fields: Vec<&'b str>,
+        fields: Vec<&'a str>,
     },
     Set {
         id: &'a str,
